/* A Bison parser, made by GNU Bison 2.3.  */

/* Skeleton interface for Bison's Yacc-like parsers in C

   Copyright (C) 1984, 1989, 1990, 2000, 2001, 2002, 2003, 2004, 2005, 2006
   Free Software Foundation, Inc.

   This program is free software; you can redistribute it and/or modify
   it under the terms of the GNU General Public License as published by
   the Free Software Foundation; either version 2, or (at your option)
   any later version.

   This program is distributed in the hope that it will be useful,
   but WITHOUT ANY WARRANTY; without even the implied warranty of
   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
   GNU General Public License for more details.

   You should have received a copy of the GNU General Public License
   along with this program; if not, write to the Free Software
   Foundation, Inc., 51 Franklin Street, Fifth Floor,
   Boston, MA 02110-1301, USA.  */

/* As a special exception, you may create a larger work that contains
   part or all of the Bison parser skeleton and distribute that work
   under terms of your choice, so long as that work isn't itself a
   parser generator using the skeleton or a modified version thereof
   as a parser skeleton.  Alternatively, if you modify or redistribute
   the parser skeleton itself, you may (at your option) remove this
   special exception, which will cause the skeleton and the resulting
   Bison output files to be licensed under the GNU General Public
   License without this special exception.

   This special exception was added by the Free Software Foundation in
   version 2.2 of Bison.  */

/* Tokens.  */
#ifndef YYTOKENTYPE
# define YYTOKENTYPE
   /* Put the tokens into the symbol table, so that GDB and other debuggers
      know about them.  */
   enum yytokentype {
     L_WORD = 258,
     L_CHAR = 259,
     L_SPC = 260,
     L_STRING = 261,
     L_TEXTUAL = 262,
     L_LSBRACKET = 263,
     L_RSBRACKET = 264,
     L_PNAME = 265,
     L_PTYPE = 266,
     L_PISPARAM = 267,
     L_PDESCR = 268,
     L_PNULLOK = 269,
     L_UNSPECVAL = 270,
     L_SIMPLE_PARAM = 271,
     L_SC = 272
   };
#endif
/* Tokens.  */
#define L_WORD 258
#define L_CHAR 259
#define L_SPC 260
#define L_STRING 261
#define L_TEXTUAL 262
#define L_LSBRACKET 263
#define L_RSBRACKET 264
#define L_PNAME 265
#define L_PTYPE 266
#define L_PISPARAM 267
#define L_PDESCR 268
#define L_PNULLOK 269
#define L_UNSPECVAL 270
#define L_SIMPLE_PARAM 271
#define L_SC 272




#if ! defined YYSTYPE && ! defined YYSTYPE_IS_DECLARED
typedef union YYSTYPE
#line 73 "parser.y"
{
void            *v;
char            *str;
GList           *list;
GdaDelimiterParamSpec     *ps;
}
/* Line 1489 of yacc.c.  */
#line 90 "parser.h"
	YYSTYPE;
# define yystype YYSTYPE /* obsolescent; will be withdrawn */
# define YYSTYPE_IS_DECLARED 1
# define YYSTYPE_IS_TRIVIAL 1
#endif

extern YYSTYPE gda_delimiterlval;

